# SupremeUtils

A python package capable of doing some useful things to help you on your code

## Installing

Python 3.8 or higher is required
Currently avaliable at [Pypi](https://pypi.org/project/SupremeUtils/)

```
pip install SupremeUtils
```

## Usage

### Examples

`test.py`
```
# Import package
from SupremeUtils import Color

# Create terminal object
terminal = Color()

terminal.error('This is an error')
terminal.warning('This is an warning')
terminal.add('This is an add')
terminal.minus('This is an minus')
terminal.info('This is an info')

```
*Written by SystemFall*
